class dynamicForm{
    async init(){
        this.date = document.getElementById('date');
        this.api_key = document.getElementById('key');
        const dt = new Date();
        this.date.value = `${dt.toLocaleDateString().split('.').reverse().join('-')}`;
        this.deviceNum = document.getElementById('num');
        this.placeSelector = document.getElementById('placeSel');
        await this.loadPlaces();
        this.dataTable = document.getElementById('dataTbl');
        this.placeSelector.addEventListener('change', this.changePlace.bind(this));
        const selectorValue =  window.localStorage.getItem('selectedPlace');
        if (selectorValue === null) this.placeSelector.selectrdIndex = 0;
        else this.placeSelector.value = selectorValue;
        this.createTable(this.placeSelector.value);
        this.sendBtn = document.getElementById('sendBtn');
        this.sendBtn.addEventListener('click', this.sendJson.bind(this));
    }

    constructor(){
        this.init();
    }

    //Обработчик загрузки сиска мест
    changePlace(){
        const key = this.placeSelector.value;
        window.localStorage.setItem('selectedPlace', key);
        this.createTable(key);
    }

    //Проверка заполненности записи перед ее отправкой
    isFilled(row){
        for (let i = 1; i < 5; i++){
            if (!(this.getTableField(row, i) === '')) return true;
        }
        return false;
    }


    //Обращение к api для отправки запроса в базу
    async sendJson(){
	let cnt=0;
        for (let i = 0; i < this.data[this.placeSelector.value].length;i++){
            if (!this.isFilled(i)) continue;
            cnt++;
            //Формирование JSON-а с данными измерений
            const content = {
                    system : {
                        Serial: this.deviceNum.value,
                        Akey: this.api_key.value
                    },
                    weather : {
                        temp : this.getTableField(i, 2),
                        humidity : this.getTableField(i, 3),
                        pressure : this.getTableField(i, 4)
                    },
                    RTC : {
                        date : this.date.value,
                        time : this.getTableField(i, 1)
                    },
                    location : this.getTableField(i, 0)
                }
                console.log(JSON.stringify(content));
                const req_content = {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(content)
                }

                const req = await fetch( `${document.URL.slice(0, -8)}klop_api/send`, req_content)
            }
        alert(`Отправлено строк: ${cnt}`);
    }

    //Начальная загрузка списков мест из файла
    async loadPlaces(){
        const res = await fetch(document.URL + "places.json")
        if (!res.ok){
            return;
        }
        this.data = await res.json();
        for (let key of Object.keys(this.data)){
            this.placeSelector.innerHTML += `<option>${key}</option>`
        }
    }

    //Формирование таблицы для выбранного набора мест
    createTable(key){
        this.dataTable.innerHTML = "<tr><th>Точка</th><th>Время</th><th>Температура</th><th>Влажность</th><th>Атм. давление</th></tr>";
        let i = 1;
        for (let place of this.data[key]){
            this.dataTable.innerHTML += `<tr class="row-${i}"><td><input class="place-field" type="text" value="${place}"></td>
                                             <td><input id="time-field" type="time" step="1"></td>
                                             <td><input id="temp-field" type="text"></td>
                                             <td><input id="hum-field" type="text"></td>
                                             <td><input id="press-field" type="text"></td></tr>`
        }
        i++;
    }

    getTableField(i, j){
        return this.dataTable.children[i+1].children[0].children[j].children[0].value
    }

}

const df = new dynamicForm();
